@@ -62,7 +62,8 @@ class EC2ImageUploader(EC2ImgUtils):
                  log_level=logging.INFO,
                  log_callback=None,
                  boot_mode=None,
-                 tpm_support=None
+                 tpm_support=None,
+                 imds_support=None
                  ):
         EC2ImgUtils.__init__(
             self,
@@ -80,6 +81,7 @@ class EC2ImageUploader(EC2ImgUtils):
         self.image_description = image_description
         self.image_name = image_name
         self.image_virt_type = image_virt_type
+        self.imds_support = imds_support
         self.inst_user_name = inst_user_name
         self.launch_ami_id = launch_ami
         self.launch_ins_type = launch_inst_type
@@ -121,6 +123,11 @@ class EC2ImageUploader(EC2ImgUtils):
             raise EC2UploadImgException(
                 'tpm_support must be one of %s' % str(tpm_versions)
             )
+        imds_versions = ['2.0', 'v2.0']
+        if imds_support and imds_support not in imds_versions:
+            raise EC2UploadImgException(
+                'imds_support must be one of %s' % str(imds_versions)
+            )
 
     def abort(self):
         """
@@ -299,7 +306,8 @@ class EC2ImageUploader(EC2ImgUtils):
                 repeat_count = self._check_wait_status(
                     wait_status,
                     error_msg,
-                    repeat_count
+                    repeat_count,
+                    skip_cleanup=True
                 )
         if self.created_volumes:
             for volume in self.created_volumes:
@@ -352,7 +360,7 @@ class EC2ImageUploader(EC2ImgUtils):
         else:
             helper_instance = self._launch_helper_instance()
         self.helper_instance = helper_instance
-        store_volume = self._create_storge_volume()
+        store_volume = self._create_storage_volume()
         self._attach_volume(store_volume)
         self._establish_ssh_connection()
         store_device_id = self._find_device_name(self.storage_volume_size)
@@ -428,7 +436,7 @@ class EC2ImageUploader(EC2ImgUtils):
         return result
 
     # ---------------------------------------------------------------------
-    def _create_storge_volume(self):
+    def _create_storage_volume(self):
         """Create the volume that will be used to store the image before
            dumping it to the new root volume"""
         return self._create_volume('%s' % self.storage_volume_size)
@@ -603,7 +611,9 @@ class EC2ImageUploader(EC2ImgUtils):
                     key_filename=self.ssh_key_private_key_file,
                     username=self.inst_user_name,
                     hostname=instance_ip,
-                    timeout=10
+                    timeout=self.ssh_timeout,
+                    banner_timeout=self.ssh_timeout,
+                    auth_timeout=self.ssh_timeout
                 )
             except (Exception, ConnectionResetError):
                 if self.log_level == logging.DEBUG:
@@ -890,6 +900,11 @@ class EC2ImageUploader(EC2ImgUtils):
             if not tpm_version.startswith('v'):
                 tpm_version = 'v%s' % tpm_version
             register_args['TpmSupport'] = tpm_version
+        if self.imds_support:
+            imds_version = self.imds_support
+            if not imds_version.startswith('v'):
+                imds_version = 'v%s' % imds_version
+            register_args['ImdsSupport'] = imds_version
 
         ami = self._connect().register_image(**register_args)
 
